summaryrefslogtreecommitdiffstats
path: root/kmyfirewall/core/kmfiptdoc.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-27 17:52:36 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-27 17:52:36 +0000
commitff419492931de3748936967da36948af7a04d7a0 (patch)
tree31a70be62d3bfb8e405d51e4b256a7210940ffe8 /kmyfirewall/core/kmfiptdoc.h
parentf1fd95abe28acef708caac65af44473461d7026c (diff)
downloadkmyfirewall-ff419492931de3748936967da36948af7a04d7a0.tar.gz
kmyfirewall-ff419492931de3748936967da36948af7a04d7a0.zip
TQt4 convert kmyfirewall
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/kmyfirewall@1238525 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kmyfirewall/core/kmfiptdoc.h')
-rw-r--r--kmyfirewall/core/kmfiptdoc.h36
1 files changed, 18 insertions, 18 deletions
diff --git a/kmyfirewall/core/kmfiptdoc.h b/kmyfirewall/core/kmfiptdoc.h
index 37f530f..39b4564 100644
--- a/kmyfirewall/core/kmfiptdoc.h
+++ b/kmyfirewall/core/kmfiptdoc.h
@@ -26,11 +26,11 @@
#include "kmfrulesetdoc.h"
// qt includes
-#include <qdict.h>
-#include <qvaluelist.h>
-#include <qptrlist.h>
-#include <qstring.h>
-#include <qobject.h>
+#include <tqdict.h>
+#include <tqvaluelist.h>
+#include <tqptrlist.h>
+#include <tqstring.h>
+#include <tqobject.h>
// kde includes
#include <kurl.h>
@@ -67,27 +67,27 @@ public:
~KMFIPTDoc();
/** Compiles the document to an iptables script */
- const QString& compile();
+ const TQString& compile();
// /** Writes the shellscrip that contains the iptables commands to settup
// the firewall to file.
// If file = QString::null a SaveAs dialog will popup. */
// KMFError* createFirewallScript( const QString& file = QString::null );
/** loads the ruleset defined by the KURL object */
- virtual void parseDocument( const KURL&, QStringList& errors );
+ virtual void parseDocument( const KURL&, TQStringList& errors );
/** Get the File dialog filter string for the document type */
- virtual const QString& getFileDialogFilter();
+ virtual const TQString& getFileDialogFilter();
- /** loads the ruleset defined by the QDomDocument object */
- virtual void loadXML( const QDomDocument&, QStringList& errors );
+ /** loads the ruleset defined by the TQDomDocument object */
+ virtual void loadXML( const TQDomDocument&, TQStringList& errors );
- /** loads the ruleset defined by the QDomNode object */
- virtual void loadXML( QDomNode, QStringList& errors );
+ /** loads the ruleset defined by the TQDomNode object */
+ virtual void loadXML( TQDomNode, TQStringList& errors );
-/* virtual void setDescription( const QString& ); */
-// virtual void setName( const QString& );
+/* virtual void setDescription( const TQString& ); */
+// virtual void setName( const TQString& );
virtual int type();
@@ -165,10 +165,10 @@ public:
};
/** Returns the IPTable with the given name if it exists */
- IPTable* table( const QString& table );
+ IPTable* table( const TQString& table );
/** Return DomDocument of this Chain */
- const QDomDocument& getDOMTree();
+ const TQDomDocument& getDOMTree();
/** Read the rule option definitions from the XML files in
@@ -67,27 +67,27 @@ public:
// /** Writes the shellscrip that contains the iptables commands to settup
// the firewall to file.
-// If file = QString::null a SaveAs dialog will popup. */
- // KMFError* createFirewallScript( const QString& file = QString::null );
+// If file = TQString() a SaveAs dialog will popup. */
+ // KMFError* createFirewallScript( const TQString& file = TQString() );
/** loads the ruleset defined by the KURL object */